"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/* eslint-disable @typescript-eslint/no-explicit-any */
const readline = require("readline");
const chalk_1 = require("chalk");
exports.chalk = chalk_1.default;
const redent = require("redent");
const ora_1 = require("ora");
// Disable colors output for testing
chalk_1.default.enabled = process.env.NODE_ENV !== 'test';
/**
 * Writes a normal message.
 * @param message The message to show.
 */
exports.log = (message, ...optionalParams) => {
    console.log(message, ...optionalParams);
};
/**
 * Writes a normal information message.
 * This is the default type you should use.
 * @param message The message to show.
 */
exports.info = (message, ...optionalParams) => {
    exports.log(chalk_1.default.reset(message), ...optionalParams);
};
/**
 * Writes a success message.
 * When something is successful.  Use sparingly.
 * @param message The message to show.
 */
exports.success = (message, ...optionalParams) => {
    exports.log(chalk_1.default.green(message), ...optionalParams);
};
/**
 * Writes a warning message.
 * This is when the user might not be getting what they're expecting.
 * @param message The message to show.
 */
exports.warn = (message, ...optionalParams) => {
    exports.log(chalk_1.default.yellow(message), ...optionalParams);
};
/**
 * Writes an error message.
 * This is when something horribly goes wrong.
 * @param message The message to show.
 */
exports.error = (message, ...optionalParams) => {
    exports.log(chalk_1.default.red(message), ...optionalParams);
};
/**
 * Writes a debug message.
 * This is for devs only.
 * @param message The message to show.
 */
exports.debug = (message, title = 'DEBUG') => {
    exports.log(chalk_1.default.magenta(`↓↓↓ --------------------[ ${title} ]-------------------- ↓↓↓`));
    exports.log(message);
    exports.log(chalk_1.default.magenta(`↑↑↑ --------------------[ ${title} ]-------------------- ↑↑↑`));
};
/**
 * Pad `input` to `width`.
 * @param input input text
 * @param width width
 */
exports.pad = (input, width) => {
    const len = Math.max(0, width - input.length);
    return input + Array(len + 1).join(' ');
};
/**
 * Indent message.
 * @param input indent text
 * @param size indent size
 */
exports.table = (obj, minCels = 20) => {
    const keys = Object.keys(obj);
    minCels = Math.max(minCels, ...keys.map(k => k.length));
    return keys.map(k => `${exports.pad(k, minCels)} ${obj[k]}`).join('\n');
};
/**
 * Indent message.
 * @param input indent text
 * @param size indent size
 */
exports.indent = (input, size = 2) => {
    return redent(input, size);
};
/**
 * Print a blank line.
 */
exports.newline = () => {
    exports.log('');
};
/**
 * Prints a divider line
 */
exports.divider = () => {
    exports.log(chalk_1.default.gray('--------------------------------------------------------------------------------'));
};
/**
 * Clear console.
 * @param title Default title
 */
exports.clear = (title) => {
    if (!process.stdout.isTTY)
        return;
    const blank = '\n'.repeat(process.stdout.rows || 30);
    exports.log(blank);
    readline.cursorTo(process.stdout, 0, 0);
    readline.clearScreenDown(process.stdout);
    title && exports.log(title);
};
/**
 * Creates a spinner and starts it up.
 * @param options The text for the spinner or an ora options.
 * @returns The Ora spinner.
 */
exports.spin = (options = '') => {
    return ora_1.default(options).start();
};
